Module mutation

Module mutation 

Mutation input types for inserts and updates.

Provides input type generation for GraphQL mutations based on table metadata.

Structs

InsertField
Represents a field in an insert input type.
InsertInput
Represents an insert input type for a table.
UpdateField
Represents a field in an update input type.
UpdateInput
Represents an update input type for a table.

Enums

InputValue
A dynamic input value that can hold different types.

Functions

is_deletable
Check if a table is deletable based on its permissions.
is_insertable
Check if a table is insertable based on its permissions.
is_updatable
Check if a table is updatable based on its permissions.