pub struct BigInt(pub i64);Expand description
BigInt scalar for 64-bit integers.
Tuple Fields
0: i64Trait Implementations
Sourceimpl InputType for BigInt
impl InputType for BigInt
Sourcetype RawValueType = BigInt
type RawValueType = BigInt
The raw type used for validator. Read more
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourcefn parse(value: Option<Value>) -> InputValueResult<Self>
fn parse(value: Option<Value>) -> InputValueResult<Self>
Parse from
Value. None represents undefined.Sourcefn as_raw_value(&self) -> Option<&Self::RawValueType>
fn as_raw_value(&self) -> Option<&Self::RawValueType>
Returns a reference to the raw value.
Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
Sourceimpl OutputType for BigInt
impl OutputType for BigInt
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourceasync fn resolve(
&self,
_: &ContextSelectionSet<'_>,
_field: &Positioned<Field>,
) -> ServerResult<Value>
async fn resolve( &self, _: &ContextSelectionSet<'_>, _field: &Positioned<Field>, ) -> ServerResult<Value>
Resolve an output value to
async_graphql::Value.Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
Sourceimpl ScalarType for BigInt
impl ScalarType for BigInt
impl Copy for BigInt
impl Eq for BigInt
impl StructuralPartialEq for BigInt