pub struct MutationField {
pub name: String,
pub table_name: String,
pub schema_name: String,
pub mutation_type: MutationType,
pub pk_columns: Vec<(String, String)>,
pub return_type: String,
pub description: Option<String>,
}Expand description
A mutation field for a table.
Fields
name: StringField name (e.g., “insertUsers”)
table_name: StringTable name
schema_name: StringSchema the table lives in
mutation_type: MutationTypeMutation type
pk_columns: Vec<(String, String)>Primary key columns, as (column name, PostgreSQL type).
Populated for by-PK mutations so the resolver can target the row by its key. Empty for bulk mutations.
return_type: StringGraphQL return type
description: Option<String>Field description
Implementations
Sourceimpl MutationField
impl MutationField
Sourcepub fn insert_fields(table: &Table, config: &SchemaConfig) -> Vec<Self>
pub fn insert_fields(table: &Table, config: &SchemaConfig) -> Vec<Self>
Create insert mutation fields for a table.
Sourcepub fn insert_fields_named(
table: &Table,
config: &SchemaConfig,
base_name: &str,
) -> Vec<Self>
pub fn insert_fields_named( table: &Table, config: &SchemaConfig, base_name: &str, ) -> Vec<Self>
As Self::insert_fields, with an explicit base name for the generated
field and type names.
Sourcepub fn update_fields(table: &Table, config: &SchemaConfig) -> Vec<Self>
pub fn update_fields(table: &Table, config: &SchemaConfig) -> Vec<Self>
Create update mutation fields for a table.
Sourcepub fn update_fields_named(
table: &Table,
config: &SchemaConfig,
base_name: &str,
) -> Vec<Self>
pub fn update_fields_named( table: &Table, config: &SchemaConfig, base_name: &str, ) -> Vec<Self>
As Self::update_fields, with an explicit base name for the generated
field and type names.
Sourcepub fn delete_fields(table: &Table, config: &SchemaConfig) -> Vec<Self>
pub fn delete_fields(table: &Table, config: &SchemaConfig) -> Vec<Self>
Create delete mutation fields for a table.
Sourcepub fn delete_fields_named(
table: &Table,
config: &SchemaConfig,
base_name: &str,
) -> Vec<Self>
pub fn delete_fields_named( table: &Table, config: &SchemaConfig, base_name: &str, ) -> Vec<Self>
As Self::delete_fields, with an explicit base name for the generated
field and type names.