Module broker

Module broker 

PostgreSQL NOTIFY message broker for GraphQL subscriptions.

This module provides a broker that listens to PostgreSQL NOTIFY events and broadcasts them to GraphQL subscription clients.

Structs

NotifyBroker
Message broker that distributes PostgreSQL NOTIFY events to subscribers.
PgNotification
A notification from PostgreSQL

Enums

BrokerError
Errors that can occur in the broker.

Functions

create_notify_trigger_sql
Generate SQL to create a notification trigger for a table.
drop_notify_trigger_sql
Generate SQL to drop a notification trigger for a table.
table_channel_name
Generate a channel name for table change notifications.