pub fn generate_subscription_fields(
_schema_cache: &SchemaCache,
generated: &GeneratedSchema,
) -> Vec<SubscriptionField>Expand description
Generate subscription fields for all tables in the schema.
pub fn generate_subscription_fields(
_schema_cache: &SchemaCache,
generated: &GeneratedSchema,
) -> Vec<SubscriptionField>Generate subscription fields for all tables in the schema.