PostgreSQL NOTIFY message broker for GraphQL subscriptions.
This module provides a broker that listens to PostgreSQL NOTIFY events and broadcasts them to GraphQL subscription clients.
Structs
- Notify
Broker - Message broker that distributes PostgreSQL NOTIFY events to subscribers.
- PgNotification
- A notification from PostgreSQL
Enums
- Broker
Error - Errors that can occur in the broker.
Functions
- create_
notify_ trigger_ sql - Generate SQL to create a notification trigger for a table.
- drop_
notify_ trigger_ sql - Generate SQL to drop a notification trigger for a table.
- table_
channel_ name - Generate a channel name for table change notifications.